@@ -2,31 +2,6 @@ from libifstate.util import logger
 from abc import ABC, abstractmethod
 
 
-class IfAttrList(list):
-    def __init__(self, l):
-        for i, v in enumerate(l):
-            if isinstance(v, dict):
-                l[i] = IfAttrDict(v)
-            elif isinstance(v, list):
-                l[i] = IfAttrList(v)
-        super().__init__(l)
-
-
-class IfAttrDict(dict):
-    def __init__(self, d):
-        for k, v in d.items():
-            if isinstance(v, dict):
-                d[k] = IfAttrDict(v)
-            elif isinstance(v, list):
-                d[k] = IfAttrList(v)
-        super().__init__(d)
-
-    def __getitem__(self, key):
-        # if not key in self:
-        #     print("booom")
-        return super().__getitem__(key)
-
-
 class Parser(ABC):
     _default_ifstates = {
         'ignore': {
@@ -69,4 +44,4 @@ class Parser(ABC):
         return a
 
     def config(self):
-        return IfAttrDict(self.merge(self._default_ifstates, self.ifstates))
+        return (self.merge(self._default_ifstates, self.ifstates))
